summaryrefslogtreecommitdiffstatshomepage
diff options
context:
space:
mode:
author Roberto Fresca <robbie@robertofresca.com>2023-04-26 00:25:39 +0200
committer Roberto Fresca <robbie@robertofresca.com>2023-04-26 00:25:39 +0200
commitd95113ec99d152c86cddbd29b3eadc6377a105b7 (patch)
tree7d078ef2e30c7c6d2351330f32defed8986e119f
parent4ee92e82209044ecfb71204ebf8526a0ba4207c9 (diff)
parent96acd9f95896969d05310cedc24c6ab09eac7fe5 (diff)
Merge branch 'master' of https://github.com/mamedev/mame
-rw-r--r--3rdparty/tap-windows6/tap-windows.h7
-rw-r--r--hash/icanguit.xml2
-rw-r--r--hash/jakks_gamekey_nk.xml2
-rw-r--r--hash/leapfrog_didj_cart.xml4
-rw-r--r--hash/leapfrog_leappad_cart.xml4
-rw-r--r--hash/leapster.xml26
-rw-r--r--hash/mobigo_cart.xml8
-rw-r--r--hash/pi_storyreader_cart.xml4
-rw-r--r--hash/vsmile_cart.xml26
-rw-r--r--hash/vsmile_cd.xml14
-rw-r--r--hash/vsmilem_cart.xml6
-rw-r--r--hash/vtech_storio_cart.xml6
-rw-r--r--src/devices/cpu/m88000/m88000.cpp10
-rw-r--r--src/devices/machine/t10mmc.cpp21
-rw-r--r--src/devices/sound/msm5232.cpp42
-rw-r--r--src/devices/sound/msm5232.h43
-rw-r--r--src/mame/cinematronics/jack.cpp64
-rwxr-xr-xsrc/mame/mame.lst1
-rw-r--r--src/mame/omron/luna_88k.cpp34
-rw-r--r--src/mame/sega/megatech.cpp2
-rw-r--r--src/mame/sega/segasp.cpp27
-rw-r--r--src/mame/skeleton/wicat.cpp6
-rw-r--r--src/osd/modules/netdev/taptun.cpp23
23 files changed, 227 insertions, 155 deletions
diff --git a/3rdparty/tap-windows6/tap-windows.h b/3rdparty/tap-windows6/tap-windows.h
index 99715343df7..42231533741 100644
--- a/3rdparty/tap-windows6/tap-windows.h
+++ b/3rdparty/tap-windows6/tap-windows.h
@@ -51,6 +51,13 @@
/* obsoletes TAP_WIN_IOCTL_CONFIG_POINT_TO_POINT */
#define TAP_WIN_IOCTL_CONFIG_TUN TAP_WIN_CONTROL_CODE (10, METHOD_BUFFERED)
+/* Control whether 802.1Q headers are added for priority */
+#define TAP_WIN_IOCTL_PRIORITY_BEHAVIOR TAP_WIN_CONTROL_CODE (11, METHOD_BUFFERED)
+#define TAP_PRIORITY_BEHAVIOR_NOPRIORITY 0
+#define TAP_PRIORITY_BEHAVIOR_ENABLED 1
+#define TAP_PRIORITY_BEHAVIOR_ADDALWAYS 2
+#define TAP_PRIORITY_BEHAVIOR_MAX 2
+
/*
* =================
* Registry keys
diff --git a/hash/icanguit.xml b/hash/icanguit.xml
index fad09b113e3..8f997871817 100644
--- a/hash/icanguit.xml
+++ b/hash/icanguit.xml
@@ -9,7 +9,7 @@ license:CC0-1.0
*Barbie Guitar Party (K9901)
*Hot Wheels Road Tunes (K9902)
- *Spongebob Squarepants Surf's Up (K9903)
+ *SpongeBob SquarePants Surf's Up (K9903)
(is there a K9904?)
diff --git a/hash/jakks_gamekey_nk.xml b/hash/jakks_gamekey_nk.xml
index c0428fc456c..7b344da50f6 100644
--- a/hash/jakks_gamekey_nk.xml
+++ b/hash/jakks_gamekey_nk.xml
@@ -34,7 +34,7 @@ license:CC0-1.0
</software>
<software name="popsnow">
- <description>Spongebob Sponge Pop &amp; Snowball Showdown (15 AUGUST 2005 D)</description>
+ <description>SpongeBob Sponge Pop &amp; Snowball Showdown (15 AUGUST 2005 D)</description>
<year>2005</year>
<publisher>JAKKS Pacific / HotGen Ltd</publisher>
<part name="cart" interface="jakks_gamekey">
diff --git a/hash/leapfrog_didj_cart.xml b/hash/leapfrog_didj_cart.xml
index 1b19c86bd56..51b06bb6881 100644
--- a/hash/leapfrog_didj_cart.xml
+++ b/hash/leapfrog_didj_cart.xml
@@ -47,13 +47,13 @@
</software>
<software name="spbobfifo" supported="no">
- <description>Nickelodeon Spongebob Squarepants - Fists of Foam (USA)</description>
+ <description>Nickelodeon SpongeBob SquarePants - Fists of Foam (USA)</description>
<year>2008</year>
<publisher>LeapFrog</publisher>
<info name="serial" value="500-13291-B"/>
<part name="cart" interface="leapfrog_didj_cart">
<dataarea name="rom" size="0x4200000" width="32" endianness="big">
- <rom loadflag="load16_word_swap" name="500-13291-B - Spongebob Squarepants - Fists of Foam (US).bin" size="0x4200000" crc="4edb2270" sha1="8a6752bcdfa94cb68f05764b808ce1142a8919ac" />
+ <rom loadflag="load16_word_swap" name="500-13291-B - SpongeBob SquarePants - Fists of Foam (US).bin" size="0x4200000" crc="4edb2270" sha1="8a6752bcdfa94cb68f05764b808ce1142a8919ac" />
</dataarea>
</part>
</software>
diff --git a/hash/leapfrog_leappad_cart.xml b/hash/leapfrog_leappad_cart.xml
index b160338380c..1cbf25c023e 100644
--- a/hash/leapfrog_leappad_cart.xml
+++ b/hash/leapfrog_leappad_cart.xml
@@ -678,7 +678,7 @@ license:CC0-1.0
</software>
<software name="spongebobg" supported="no">
- <description>Spongebob Schwammkopf - Meeres-Geschichten (Germany)</description>
+ <description>SpongeBob Schwammkopf - Meeres-Geschichten (Germany)</description>
<year>2003</year>
<publisher>LeapFrog</publisher>
<info name="serial" value="500-11540"/>
@@ -687,7 +687,7 @@ license:CC0-1.0
<feature name="pcb_rev" value="Rev.00"/>
<feature name="u1" value="OKI 32(J)"/> <!-- ROM on epoxy blob, but type silkscreened on the PCB -->
<dataarea name="rom" size="0x400000">
- <rom name="500-11540 - Spongebob Schwammkopf - Meeres-Geschichten (GER).bin" size="0x400000" crc="cf81398e" sha1="52c8cd56c49d53a20129b3870527f180e22683b4" />
+ <rom name="500-11540 - SpongeBob Schwammkopf - Meeres-Geschichten (GER).bin" size="0x400000" crc="cf81398e" sha1="52c8cd56c49d53a20129b3870527f180e22683b4" />
</dataarea>
</part>
</software>
diff --git a/hash/leapster.xml b/hash/leapster.xml
index ac563f58619..ceda3abd6f9 100644
--- a/hash/leapster.xml
+++ b/hash/leapster.xml
@@ -7,7 +7,7 @@ Known games listed by part-no, (*) denotes undumped, (**) denotes acquired but n
| PART-NO |LAN| GAME TITLE | CARTRIDGE-TYPE | DUMPED | Notes
===============================================================================================================================
-| 500-01168 |ENG| Spongebob Squarepants - Saves the Day | LEAPSTER | YES | Same ROM as 500-11002
+| 500-01168 |ENG| SpongeBob SquarePants - Saves the Day | LEAPSTER | YES | Same ROM as 500-11002
| 500-01169 |ENG| 1st Grade | LEAPSTER | YES | Same ROM as 500-11000
| 500-01170 |ENG| Kindergarten | LEAPSTER | YES |
| 500-01171 |ENG| Dora the Explorer - Animal Rescuer | LEAPSTER | YES |
@@ -23,14 +23,14 @@ Known games listed by part-no, (*) denotes undumped, (**) denotes acquired but n
| 500-10812-A |ENG| The Incredibles | LEAPSTER | YES |
| 500-10825-A |ENG| Spider-Man - The Case of the Sinister Speller | LEAPSTER | YES |
| 500-10829-A |ENG| Reading with Phonics - Mole's Huge Nose | LEAPSTER | YES |
-| 500-10933-A |GER| Spongebob Schwammkopf hat alles im Griff | LEAPSTER | YES |
+| 500-10933-A |GER| SpongeBob Schwammkopf hat alles im Griff | LEAPSTER | YES |
| 500-10934-A |GER| Vorschule | LEAPSTER | YES |
| 500-10935-A |GER| Grundschule 1 | LEAPSTER | YES |
| 500-10957-A |ENG| 2nd Grade - Musical Menace | LEAPSTER | YES |
| 500-10999 |ENG| Kindergarten | LEAPSTER | YES |
| 500-11000 |ENG| 1st Grade | LEAPSTER | YES | Same ROM as 500-01169
| 500-11001 |ENG| Dora the Explorer - Wildlife Rescue | LEAPSTER | YES | Two sets with the same serial
-| 500-11002 |ENG| Spongebob Squarepants - Saves the Day | LEAPSTER | YES | Same ROM as 500-01168
+| 500-11002 |ENG| SpongeBob SquarePants - Saves the Day | LEAPSTER | YES | Same ROM as 500-01168
| 500-11003 |ENG| Mr. Pencil's Learn to Draw & Write | LEAPSTER | YES | Two sets with the same serial
| 500-11004 |ENG| Math Baseball | LEAPSTER | YES | Same ROM as 500-10441
| 500-11006 |ENG| Talking WORDS Factory | LEAPSTER | YES |
@@ -57,7 +57,7 @@ Known games listed by part-no, (*) denotes undumped, (**) denotes acquired but n
| 500-11898-A |ENG| Scholastic - Math Missions | LEAPSTER | YES |
| 500-11903-A |ENG| Spider-Man - The Case of The Sinister Speller | LEAPSTER L-MAX | YES |
| 500-11904-A |ENG| Dora the Explorer - Wildlife Rescue | LEAPSTER L-MAX | YES |
-| 500-11905-A |ENG| Spongebob Squarepants - Saves the Day | LEAPSTER L-MAX | YES |
+| 500-11905-A |ENG| SpongeBob SquarePants - Saves the Day | LEAPSTER L-MAX | YES |
| 500-11929-A |ENG| Scholastic I Spy - Challenger | LEAPSTER | YES |
| 500-11966-A |ENG| Disney Princess | LEAPSTER | YES |
| 500-11972-A |GER| Batman - Multipliziere, dividiere und reagiere | LEAPSTER | YES |
@@ -110,7 +110,7 @@ Known games listed by part-no, (*) denotes undumped, (**) denotes acquired but n
| 500-12713-A |ENG| Disney Princess - Worlds of Enchantment | LEAPSTER | YES |
| 500-12715-A |ENG| Foster's Home for Imaginary Friends | LEAPSTER | YES |
| 500-12718-A |ENG| Go Diego Go! - Animal Rescuer | LEAPSTER | YES |
-| 500-12719-A |ENG| Spongebob Squarepants - Through The Wormhole | LEAPSTER | YES |
+| 500-12719-A |ENG| SpongeBob SquarePants - Through The Wormhole | LEAPSTER | YES |
| 500-12738-A |GER| Ratatouille | LEAPSTER | YES |
| 500-12798-A |UK | Noddy - Rainbow Adventures | LEAPSTER | NO |
| 500-12799-A |FRA| Oui-Oui - Aventures Au Pays Des Jouet | LEAPSTER | YES |
@@ -118,7 +118,7 @@ Known games listed by part-no, (*) denotes undumped, (**) denotes acquired but n
| 500-12824-A |SPA| Perrito Club - ¡Adopta Un Nuevo Amiguito Y Aprende! | LEAPSTER | YES |
| 500-12830-A |SPA| The Batman - El Poder De Los Números | LEAPSTER | YES |
| 500-13272-A |ENG| Wall-E | LEAPSTER | YES |
-| 500-13273-A |GER| Spongebob Schwammkopf - Zeitreise durch das Wurmloch | LEAPSTER | YES |
+| 500-13273-A |GER| SpongeBob Schwammkopf - Zeitreise durch das Wurmloch | LEAPSTER | YES |
| 500-13298-A |ENG| I Spy - Treasure Hunt! | LEAPSTER | YES |
| 500-13299-A |ENG| Scholastic OutWit! | LEAPSTER | YES |
| 500-13306-A |ENG| Star Wars - Jedi Math | LEAPSTER | YES |
@@ -133,7 +133,7 @@ Known games listed by part-no, (*) denotes undumped, (**) denotes acquired but n
| 500-13446-A |ENG| Pet Pals | LEAPSTER | YES |
| 500-13447-A |ENG| Go Diego Go! - Animal Rescuer | LEAPSTER | YES |
| 500-13448-A |ENG| Disney Princess - Worlds of Enchantment | LEAPSTER | YES |
-| 500-13451-A |ENG| Spongebob Squarepants - Saves the Day | LEAPSTER | YES |
+| 500-13451-A |ENG| SpongeBob SquarePants - Saves the Day | LEAPSTER | YES |
| 500-13453-A |ENG| The Backyardigans | LEAPSTER | YES |
| 500-13470-A |UK | Star Wars - Jedi Maths | LEAPSTER | NO |
| 500-13472-A |ENG| Star Wars - Jedi Reading | LEAPSTER | YES |
@@ -1304,7 +1304,7 @@ Entries are ordered by title of the parent, clones are list after the parent, Le
</software>
<software name="spongeb" supported="no">
- <description>Spongebob Squarepants - Saves the Day (USA)</description>
+ <description>SpongeBob SquarePants - Saves the Day (USA)</description>
<year>2003</year>
<publisher>LeapFrog</publisher>
<info name="serial" value="500-13451-A" />
@@ -1316,7 +1316,7 @@ Entries are ordered by title of the parent, clones are list after the parent, Le
</software>
<software name="spongeba" cloneof="spongeb" supported="no">
- <description>Spongebob Squarepants - Saves the Day (USA, alt)</description>
+ <description>SpongeBob SquarePants - Saves the Day (USA, alt)</description>
<year>2003</year>
<publisher>LeapFrog</publisher>
<info name="serial" value="500-11002" /> <!-- Same ROM as 500-01168 -->
@@ -1340,7 +1340,7 @@ Entries are ordered by title of the parent, clones are list after the parent, Le
</software>
<software name="spongebg" cloneof="spongeb" supported="no">
- <description>Spongebob Schwammkopf Hat Alles im Griff (Germany)</description>
+ <description>SpongeBob Schwammkopf Hat Alles im Griff (Germany)</description>
<year>2003</year>
<publisher>LeapFrog</publisher>
<info name="serial" value="500-10933-A" />
@@ -1352,7 +1352,7 @@ Entries are ordered by title of the parent, clones are list after the parent, Le
</software>
<software name="spongewrm" supported="no">
- <description>Spongebob Squarepants - Through The Wormhole (USA)</description>
+ <description>SpongeBob SquarePants - Through The Wormhole (USA)</description>
<year>2003</year>
<publisher>LeapFrog</publisher>
<info name="serial" value="500-12719-A" />
@@ -1364,7 +1364,7 @@ Entries are ordered by title of the parent, clones are list after the parent, Le
</software>
<software name="spongewrmg" cloneof="spongewrm" supported="no">
- <description>Spongebob Schwammkopf - Zeitreise durch das Wurmloch (Germany)</description>
+ <description>SpongeBob Schwammkopf - Zeitreise durch das Wurmloch (Germany)</description>
<year>2003</year>
<publisher>LeapFrog</publisher>
<info name="serial" value="500-13273-A" />
@@ -1763,7 +1763,7 @@ Entries are ordered by title of the parent, clones are list after the parent, Le
</software>
<software name="spongeblmx" cloneof="spongeb" supported="no">
- <description>Spongebob Squarepants - Saves the Day (USA, L-MAX)</description>
+ <description>SpongeBob SquarePants - Saves the Day (USA, L-MAX)</description>
<year>2005</year>
<publisher>LeapFrog</publisher>
<info name="serial" value="500-11905-A" />
diff --git a/hash/mobigo_cart.xml b/hash/mobigo_cart.xml
index 2670c84ebca..44b9810eb15 100644
--- a/hash/mobigo_cart.xml
+++ b/hash/mobigo_cart.xml
@@ -360,25 +360,25 @@ license:CC0-1.0
</software>
<software name="spongeb" supported="no">
- <description>Nickelodeon Spongebob SquarePants - Defending the Secret Formula (USA)</description>
+ <description>Nickelodeon SpongeBob SquarePants - Defending the Secret Formula (USA)</description>
<year>2011</year>
<publisher>VTech</publisher>
<info name="serial" value="80-251500(US)"/>
<part name="cart" interface="mobigo_cart">
<dataarea name="rom" size="0x1000000">
- <rom name="80-251500 - Spongebob SquarePants - Defending the Secret Formula (US).bin" size="0x1000000" crc="85266243" sha1="4ffd4ca308d1d3419396e706892ff6eff23d8cd0"/>
+ <rom name="80-251500 - SpongeBob SquarePants - Defending the Secret Formula (US).bin" size="0x1000000" crc="85266243" sha1="4ffd4ca308d1d3419396e706892ff6eff23d8cd0"/>
</dataarea>
</part>
</software>
<software name="spongebg" cloneof="spongeb" supported="no">
- <description>Nickelodeon Spongebob Schwammkopf - Rette das Geheimrezept (Germany)</description>
+ <description>Nickelodeon SpongeBob Schwammkopf - Rette das Geheimrezept (Germany)</description>
<year>2011</year>
<publisher>VTech</publisher>
<info name="serial" value="80-251504(GER)"/>
<part name="cart" interface="mobigo_cart">
<dataarea name="rom" size="0x1000000">
- <rom name="80-251504 - Spongebob Schwammkopf - Rette das Geheimrezept (GER).bin" size="0x1000000" crc="19efae9e" sha1="5c3eeb04cdec48cb92c5410ceef57e4b60adeeee"/>
+ <rom name="80-251504 - SpongeBob Schwammkopf - Rette das Geheimrezept (GER).bin" size="0x1000000" crc="19efae9e" sha1="5c3eeb04cdec48cb92c5410ceef57e4b60adeeee"/>
</dataarea>
</part>
</software>
diff --git a/hash/pi_storyreader_cart.xml b/hash/pi_storyreader_cart.xml
index 712feba55cc..46fe7e30873 100644
--- a/hash/pi_storyreader_cart.xml
+++ b/hash/pi_storyreader_cart.xml
@@ -228,7 +228,7 @@ license:CC0-1.0
</software>
<software name="srsbobgpw" supported="no">
- <description>Spongebob Squarepants Grand Price Winner!</description>
+ <description>SpongeBob SquarePants Grand Price Winner!</description>
<year>200?</year>
<publisher>Publications International Ltd. / Disney</publisher>
<info name="serial" value="01449" />
@@ -240,7 +240,7 @@ license:CC0-1.0
</software>
<software name="srsbodobl3" supported="no">
- <description>Spongebob Squarepants Grand Price Winner! / Dora's Garden Adventure / Blue's Perfect Picnic Spot</description>
+ <description>SpongeBob SquarePants Grand Price Winner! / Dora's Garden Adventure / Blue's Perfect Picnic Spot</description>
<year>200?</year>
<publisher>Publications International Ltd. / Disney</publisher>
<info name="serial" value="30376" />
diff --git a/hash/vsmile_cart.xml b/hash/vsmile_cart.xml
index 3f053b24fec..f4b83c2bf4b 100644
--- a/hash/vsmile_cart.xml
+++ b/hash/vsmile_cart.xml
@@ -403,12 +403,12 @@ Regular game cartridges
| XX | 80-092427(SP) | Buscando a Nemo - Los Descubrimientos de Nemo (52-92427(SP) on back label) |
| | (CN) | 海底总动员 |
+========+===================+================================================================================================+
-| XX | 80-092440(US) | Spongebob Squarepants - A Day In The Life of A Sponge |
-| XX | 80-092441(IT) | Spongebob - Un giorno da Spugna (no serial printed on cart) |
-| XX | 80-092442(NL) | Spongebob Squarepants - Een Dag uit het Leven van een Spons (52-92442(NL) on back label) |
-| | 80-092443(UK) | Spongebob Squarepants - A Day In The Life of A Sponge |
-| XX | 80-092444(GE) | Spongebob Schwammkopf - Der Tag des Schwamms |
-| XX | 80-092444(GE) | Spongebob Schwammkopf - Der Tag des Schwamms (rev. 1) |
+| XX | 80-092440(US) | SpongeBob SquarePants - A Day In The Life of A Sponge |
+| XX | 80-092441(IT) | SpongeBob - Un giorno da Spugna (no serial printed on cart) |
+| XX | 80-092442(NL) | SpongeBob SquarePants - Een Dag uit het Leven van een Spons (52-92442(NL) on back label) |
+| | 80-092443(UK) | SpongeBob SquarePants - A Day In The Life of A Sponge |
+| XX | 80-092444(GE) | SpongeBob Schwammkopf - Der Tag des Schwamms |
+| XX | 80-092444(GE) | SpongeBob Schwammkopf - Der Tag des Schwamms (rev. 1) |
| XX | 80-092445(FR) | Bob L'éponge - Une journée dans la vie d'une éponge |
| XX | 80-092447(SP) | Bob Esponja - Un día en la vida de una esponja (52-92447(SP) on back label) |
+========+===================+================================================================================================+
@@ -4137,7 +4137,7 @@ V.Smile Smartbook Smartidges (need a Smartbook touch tablet connected to a regul
</software>
<software name="spongeb">
- <description>Nickelodeon Spongebob Squarepants - A Day in the Life of a Sponge (USA)</description>
+ <description>Nickelodeon SpongeBob SquarePants - A Day in the Life of a Sponge (USA)</description>
<year>2005?</year>
<publisher>VTech</publisher>
<info name="serial" value="80-092440(US)" />
@@ -4154,7 +4154,7 @@ V.Smile Smartbook Smartidges (need a Smartbook touch tablet connected to a regul
</software>
<software name="spongebit" cloneof="spongeb">
- <description>Nickelodeon Spongebob - Un giorno da Spugna (Italy)</description>
+ <description>Nickelodeon SpongeBob - Un giorno da Spugna (Italy)</description>
<year>2006</year>
<publisher>VTech / Giochi Preziosi</publisher>
<info name="serial" value="80-092441(IT)" /> <!-- Serial not printed on cart -->
@@ -4163,13 +4163,13 @@ V.Smile Smartbook Smartidges (need a Smartbook touch tablet connected to a regul
<feature name="cart_type" value="lilac" />
<feature name="u1" value="" />
<dataarea name="rom" size="0x800000">
- <rom name="Spongebob - Un giorno da Spugna (Italy).bin" size="0x800000" crc="0f8708f3" sha1="0788e5d434299703ce61559eac32160bf4f51086" />
+ <rom name="SpongeBob - Un giorno da Spugna (Italy).bin" size="0x800000" crc="0f8708f3" sha1="0788e5d434299703ce61559eac32160bf4f51086" />
</dataarea>
</part>
</software>
<software name="spongebnl" cloneof="spongeb">
- <description>Nickelodeon Spongebob Squarepants - Een Dag uit het Leven van een Spons (Netherlands)</description>
+ <description>Nickelodeon SpongeBob SquarePants - Een Dag uit het Leven van een Spons (Netherlands)</description>
<year>2006</year>
<publisher>VTech / Giochi Preziosi</publisher>
<info name="serial" value="80-092442(NL)" /> <!-- Serial not printed on cart -->
@@ -4178,13 +4178,13 @@ V.Smile Smartbook Smartidges (need a Smartbook touch tablet connected to a regul
<feature name="cart_type" value="lilac" />
<feature name="u1" value="" />
<dataarea name="rom" size="0x800000">
- <rom name="52-92442 - Spongebob Squarepants - Een Dag uit het Leven van een Spons (NL).bin" size="0x800000" crc="7b2ec510" sha1="d446c88dc557df23a51a48b11c8cee42e86ae1ac" />
+ <rom name="52-92442 - SpongeBob SquarePants - Een Dag uit het Leven van een Spons (NL).bin" size="0x800000" crc="7b2ec510" sha1="d446c88dc557df23a51a48b11c8cee42e86ae1ac" />
</dataarea>
</part>
</software>
<software name="spongebger1" cloneof="spongeb">
- <description>Nickelodeon Spongebob Schwammkopf - Der Tag des Schwamms (Germany, rev. 1)</description>
+ <description>Nickelodeon SpongeBob Schwammkopf - Der Tag des Schwamms (Germany, rev. 1)</description>
<year>2005?</year>
<publisher>VTech</publisher>
<info name="serial" value="80-092444(GE)" />
@@ -4201,7 +4201,7 @@ V.Smile Smartbook Smartidges (need a Smartbook touch tablet connected to a regul
</software>
<software name="spongebge" cloneof="spongeb">
- <description>Nickelodeon Spongebob Schwammkopf - Der Tag des Schwamms (Germany)</description>
+ <description>Nickelodeon SpongeBob Schwammkopf - Der Tag des Schwamms (Germany)</description>
<year>2005?</year>
<publisher>VTech</publisher>
<info name="serial" value="80-092444(GE)" />
diff --git a/hash/vsmile_cd.xml b/hash/vsmile_cd.xml
index 4bae545b062..77102ae9ea7 100644
--- a/hash/vsmile_cd.xml
+++ b/hash/vsmile_cd.xml
@@ -30,9 +30,9 @@ ________________________________________________________________________________
| 80-093025(FR) | Les Indestructibles - Les Indestructibles à la Rescousse
*** | 80-093027(SP) | Los Increíbles - Misión Increíble
__________________________________________________________________________________________
- *** | 80-093040(US) | Nickelodeon SpongeBob Squarepants - Idea Sponge [Needs revision checking]
- *** | 80-093040(US) | Nickelodeon SpongeBob Squarepants - Idea Sponge (Rev. 1)
- *** | 80-093040(US) | Nickelodeon SpongeBob Squarepants - Idea Sponge (Rev. 2)
+ *** | 80-093040(US) | Nickelodeon SpongeBob SquarePants - Idea Sponge [Needs revision checking]
+ *** | 80-093040(US) | Nickelodeon SpongeBob SquarePants - Idea Sponge (Rev. 1)
+ *** | 80-093040(US) | Nickelodeon SpongeBob SquarePants - Idea Sponge (Rev. 2)
*** | 80-093044(GE) | Nick SpongeBob Schwammkopf - Ein Schwamm voller Ideen
| 80-093045(FR) | Nickelodeon Bob L'éponge - Une Idée Spongieuse
*** | 80-093047(SP) | Nickelodeon Bob Esponja - Misión Esponja
@@ -85,7 +85,7 @@ ________________________________________________________________________________
__________________________________________________________________________________________
-->
-<!-- CloneCD images are not fully supported by CHDMAN, thus the "Nickelodeon SpongeBob Squarepants - Idea Sponge (USA)" (spongeis) image
+<!-- CloneCD images are not fully supported by CHDMAN, thus the "Nickelodeon SpongeBob SquarePants - Idea Sponge (USA)" (spongeis) image
might need to be recreated at a later stage from the original disk -->
<softwarelist name="vsmile_cd" description="VTech V.Flash/V.Smile Pro V.Disc images">
@@ -561,7 +561,7 @@ ________________________________________________________________________________
Ring 2: "*59-93040-000-000*", "IFPI LQ24", "IFPI 9QH8", "59-93040-000"
-->
<software name="spongeisr2" supported="no">
- <description>Nickelodeon SpongeBob Squarepants - Idea Sponge (USA, Rev. 2)</description>
+ <description>Nickelodeon SpongeBob SquarePants - Idea Sponge (USA, Rev. 2)</description>
<year>200?</year>
<publisher>VTech</publisher>
<info name="serial" value="80-093040" />
@@ -580,7 +580,7 @@ ________________________________________________________________________________
Ring 1: "*59-93040-000-000", "IFPI LQ50", "IFPI 9QH8", "59-93040-000"
-->
<software name="spongeisr1" cloneof="spongeisr2" supported="no">
- <description>Nickelodeon SpongeBob Squarepants - Idea Sponge (USA, Rev. 1)</description>
+ <description>Nickelodeon SpongeBob SquarePants - Idea Sponge (USA, Rev. 1)</description>
<year>200?</year>
<publisher>VTech</publisher>
<info name="serial" value="80-093040" />
@@ -600,7 +600,7 @@ ________________________________________________________________________________
<rom name="spongebob squarepants - idea sponge (us).img" size="373038960" crc="f3dcd059" sha1="bc70d3a4017b6282bea065e4ed8a05c601471069" />
<rom name="spongebob squarepants - idea sponge (us).sub" size="15226080" crc="f8ef603f" sha1="84515fb53c4de9a0072dc051d365b1cbc1065b0f" />
-->
- <description>Nickelodeon SpongeBob Squarepants - Idea Sponge (USA)</description>
+ <description>Nickelodeon SpongeBob SquarePants - Idea Sponge (USA)</description>
<year>200?</year>
<publisher>VTech</publisher>
<part name="cdrom" interface="vsmile_vdisk">
diff --git a/hash/vsmilem_cart.xml b/hash/vsmilem_cart.xml
index 8be4ce72107..d4b4c0b40d5 100644
--- a/hash/vsmilem_cart.xml
+++ b/hash/vsmilem_cart.xml
@@ -231,8 +231,8 @@ Language:
| XX | 80-084625(FR) | Le Monde de Nemo - Nemo à la decourverte de l'océan |
| | 80-084627(SP) | Buscando a Nemo - Los Descubrimientos de Nemo |
+========+===================+===========================================================================================+
-| | 80-084640(US) | <Unknown> (Should be Orange colored Spongebob) |
-| XX | 80-084644(GE) | Spongebob Schwammkopf - Der Tag des Schwamms |
+| | 80-084640(US) | <Unknown> (Should be Orange colored SpongeBob) |
+| XX | 80-084644(GE) | SpongeBob Schwammkopf - Der Tag des Schwamms |
| | 80-084647(SP) | Bob Esponja - Un día en la vida de una esponja |
+========+===================+===========================================================================================+
@@ -1310,7 +1310,7 @@ Language:
</software>
<software name="spongebmge">
- <description>Nickelodeon Spongebob Schwammkopf - Der Tag des Schwamms (Germany)</description>
+ <description>Nickelodeon SpongeBob Schwammkopf - Der Tag des Schwamms (Germany)</description>
<year>2011</year>
<publisher>VTech</publisher>
<info name="serial" value="80-084644(GE)" />
diff --git a/hash/vtech_storio_cart.xml b/hash/vtech_storio_cart.xml
index 56c738deeb8..8f93714008f 100644
--- a/hash/vtech_storio_cart.xml
+++ b/hash/vtech_storio_cart.xml
@@ -74,7 +74,7 @@ license:CC0-1.0
| 80-281204(GER) | Disney/Pixar Cars Toon - Hook in Tokyo
| 80-281300(US) | Sesame Street - The Happy Scientists
| 80-281400(US) | SpongeBob SquarePants - Model Sponge
- XX | 80-281404(GER) | Spongebob Schwammkopf - Ein Schwamm will nach oben
+ XX | 80-281404(GER) | SpongeBob Schwammkopf - Ein Schwamm will nach oben
| 80-281405(FR) | Bob L'éponge - Bob, la star des éponges
| 80-281422(SP) | Bob Esponja - Modelo Esponja
| 80-281500(US) | Tangled
@@ -204,12 +204,12 @@ license:CC0-1.0
</software>
<software name="spongbobgr" supported="no">
- <description>Spongebob Schwammkopf - Ein Schwamm will nach oben (Germany)</description>
+ <description>SpongeBob Schwammkopf - Ein Schwamm will nach oben (Germany)</description>
<year>2011</year>
<publisher>VTech</publisher>
<part name="cart" interface="vtech_storio_cart">
<dataarea name="rom" size="0x4200000">
- <rom name="80-281404 - Spongebob Schwammkopf - Ein Schwamm will nach oben (GER).bin" size="0x4200000" crc="f1a68329" sha1="95c39150ab86233575f4f32574f7077436077adf" />
+ <rom name="80-281404 - SpongeBob Schwammkopf - Ein Schwamm will nach oben (GER).bin" size="0x4200000" crc="f1a68329" sha1="95c39150ab86233575f4f32574f7077436077adf" />
</dataarea>
</part>
</software>
diff --git a/src/devices/cpu/m88000/m88000.cpp b/src/devices/cpu/m88000/m88000.cpp
index 7fcea8dfece..9f2f2c65aae 100644
--- a/src/devices/cpu/m88000/m88000.cpp
+++ b/src/devices/cpu/m88000/m88000.cpp
@@ -794,7 +794,7 @@ void mc88100_device::execute(u32 const inst)
u32 const data = m_r[S1] + ~m_r[S2] + 1;
// compute borrow out
- if (carry(m_r[S1], ~m_r[S2], data))
+ if (carry(m_r[S1], ~m_r[S2] + 1, data))
m_cr[PSR] |= PSR_C;
else
m_cr[PSR] &= ~PSR_C;
@@ -810,7 +810,7 @@ void mc88100_device::execute(u32 const inst)
u32 const data = m_r[S1] + ~m_r[S2] + !bool(m_cr[PSR] & PSR_C);
// compute borrow out
- if (carry(m_r[S1], ~m_r[S2], data))
+ if (carry(m_r[S1], ~m_r[S2] + !bool(m_cr[PSR] & PSR_C), data))
m_cr[PSR] |= PSR_C;
else
m_cr[PSR] &= ~PSR_C;
@@ -901,7 +901,7 @@ void mc88100_device::execute(u32 const inst)
u32 const data = m_r[S1] + ~m_r[S2] + 1;
// compute borrow out
- if (carry(m_r[S1], ~m_r[S2], data))
+ if (carry(m_r[S1], ~m_r[S2] + 1, data))
m_cr[PSR] |= PSR_C;
else
m_cr[PSR] &= ~PSR_C;
@@ -917,7 +917,7 @@ void mc88100_device::execute(u32 const inst)
u32 const data = m_r[S1] + ~m_r[S2] + !bool(m_cr[PSR] & PSR_C);
// compute borrow out
- if (carry(m_r[S1], ~m_r[S2], data))
+ if (carry(m_r[S1], ~m_r[S2] + !bool(m_cr[PSR] & PSR_C), data))
m_cr[PSR] |= PSR_C;
else
m_cr[PSR] &= ~PSR_C;
@@ -1453,7 +1453,7 @@ u32 mc88100_device::cmp(u32 const src1, u32 const src2) const
bool mc88100_device::carry(u32 const src1, u32 const src2, u32 const dest) const
{
- return ((BIT(src2, 31) && BIT(src1, 31)) || (!BIT(dest, 31) && (BIT(src2, 31) || BIT(src1, 31))));
+ return BIT((src1 & src2) ^ ((src1 ^ src2) & ~dest), 31);
}
bool mc88100_device::overflow(u32 const src1, u32 const src2, u32 const dest) const
diff --git a/src/devices/sound/msm5232.h b/src/devices/sound/msm5232.h
index 552cd7669e3..56b562b2c76 100644
--- a/src/devices/sound/msm5232.h
+++ b/src/devices/sound/msm5232.h
@@ -6,8 +6,7 @@
#pragma once
-class msm5232_device : public device_t,
- public device_sound_interface
+class msm5232_device : public device_t, public device_sound_interface
{
public:
msm5232_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock);
@@ -35,24 +34,24 @@ private:
int TG_count_period;
int TG_count;
- uint8_t TG_cnt; /* 7 bits binary counter (frequency output) */
- uint8_t TG_out16; /* bit number (of TG_cnt) for 16' output */
- uint8_t TG_out8; /* bit number (of TG_cnt) for 8' output */
- uint8_t TG_out4; /* bit number (of TG_cnt) for 4' output */
- uint8_t TG_out2; /* bit number (of TG_cnt) for 2' output */
+ uint8_t TG_cnt; // 7 bits binary counter (frequency output)
+ uint8_t TG_out16; // bit number (of TG_cnt) for 16' output
+ uint8_t TG_out8; // bit number (of TG_cnt) for 8' output
+ uint8_t TG_out4; // bit number (of TG_cnt) for 4' output
+ uint8_t TG_out2; // bit number (of TG_cnt) for 2' output
int egvol;
int eg_sect;
int counter;
int eg;
- uint8_t eg_arm; /* attack/release mode */
+ uint8_t eg_arm; // attack/release mode
double ar_rate;
double dr_rate;
double rr_rate;
- int pitch; /* current pitch data */
+ int pitch; // current pitch data
int GF;
};
@@ -62,32 +61,32 @@ private:
VOICE m_voi[8];
- uint32_t m_EN_out16[2]; /* enable 16' output masks for both groups (0-disabled ; ~0 -enabled) */
- uint32_t m_EN_out8[2]; /* enable 8' output masks */
- uint32_t m_EN_out4[2]; /* enable 4' output masks */
- uint32_t m_EN_out2[2]; /* enable 2' output masks */
+ uint32_t m_EN_out16[2]; // enable 16' output masks for both groups (0-disabled ; ~0 -enabled)
+ uint32_t m_EN_out8[2]; // enable 8' output masks
+ uint32_t m_EN_out4[2]; // enable 4' output masks
+ uint32_t m_EN_out2[2]; // enable 2' output masks
int m_noise_cnt;
int m_noise_step;
int m_noise_rng;
- int m_noise_clocks; /* number of the noise_rng (output) level changes */
+ int m_noise_clocks; // number of the noise_rng (output) level changes
unsigned int m_UpdateStep;
- /* rate tables */
+ // rate tables
double m_ar_tbl[8];
double m_dr_tbl[16];
- uint8_t m_control1;
- uint8_t m_control2;
+ uint8_t m_control1;
+ uint8_t m_control2;
- int m_gate; /* current state of the GATE output */
+ int m_gate; // current state of the GATE output
- int m_chip_clock; /* chip clock in Hz */
- int m_rate; /* sample rate in Hz */
+ int m_chip_clock; // chip clock in Hz
+ int m_rate; // sample rate in Hz
- double m_external_capacity[8]; /* in Farads, eg 0.39e-6 = 0.36 uF (microFarads) */
- devcb_write_line m_gate_handler_cb;/* callback called when the GATE output pin changes state */
+ double m_external_capacitance[8]; // in Farads, eg 0.39e-6 = 0.36 uF (microFarads)
+ devcb_write_line m_gate_handler_cb;// callback called when the GATE output pin changes state
void init_tables();
void init_voice(int i);
diff --git a/src/mame/cinematronics/jack.cpp b/src/mame/cinematronics/jack.cpp
index 9a17fb8caa9..718f1be21f7 100644
--- a/src/mame/cinematronics/jack.cpp
+++ b/src/mame/cinematronics/jack.cpp
@@ -583,27 +583,37 @@ static INPUT_PORTS_START( tripool )
PORT_DIPSETTING( 0x08, DEF_STR( 3C_1C ) )
PORT_DIPSETTING( 0x04, DEF_STR( 2C_1C ) )
PORT_DIPSETTING( 0x00, DEF_STR( 1C_1C ) )
- PORT_DIPUNKNOWN_DIPLOC( 0x10, 0x00, "SW1:!5" )
- PORT_DIPUNKNOWN_DIPLOC( 0x20, 0x00, "SW1:!6" )
- PORT_DIPUNKNOWN_DIPLOC( 0x40, 0x00, "SW1:!7" )
- PORT_DIPUNKNOWN_DIPLOC( 0x80, 0x00, "SW1:!8" )
+ PORT_DIPNAME( 0x10, 0x00, DEF_STR( Lives ) ) PORT_DIPLOCATION("SW1:!5")
+ PORT_DIPSETTING( 0x00, "3" )
+ PORT_DIPSETTING( 0x10, "5" )
+ PORT_DIPNAME( 0x20, 0x00, "Bonus Life (Game A)" ) PORT_DIPLOCATION("SW1:!6")
+ PORT_DIPSETTING( 0x00, "Every 100" )
+ PORT_DIPSETTING( 0x20, "Every 200" )
+ PORT_DIPNAME( 0x40, 0x00, "Bonus Life (Game B)" ) PORT_DIPLOCATION("SW1:!7")
+ PORT_DIPSETTING( 0x00, "100, 200, Every 150" )
+ PORT_DIPSETTING( 0x40, "Every 200" )
+ PORT_DIPNAME( 0x80, 0x00, "Bonus Life (Game C)" ) PORT_DIPLOCATION("SW1:!8")
+ PORT_DIPSETTING( 0x00, "20, 50, Every 50" )
+ PORT_DIPSETTING( 0x80, "50, 100, Every 100" )
PORT_START("DSW2")
- PORT_DIPUNKNOWN_DIPLOC( 0x01, 0x00, "SW2:!1" )
- PORT_DIPUNKNOWN_DIPLOC( 0x02, 0x00, "SW2:!2" )
- PORT_DIPUNKNOWN_DIPLOC( 0x04, 0x00, "SW2:!3" )
- PORT_DIPUNKNOWN_DIPLOC( 0x08, 0x00, "SW2:!4" )
- PORT_DIPUNKNOWN_DIPLOC( 0x10, 0x00, "SW2:!5" )
- PORT_DIPUNKNOWN_DIPLOC( 0x20, 0x00, "SW2:!6" )
- PORT_DIPUNKNOWN_DIPLOC( 0x40, 0x00, "SW2:!7" )
- PORT_DIPUNKNOWN_DIPLOC( 0x80, 0x00, "SW2:!8" )
+ PORT_DIPNAME( 0x01, 0x01, DEF_STR( Cabinet ) ) PORT_DIPLOCATION("SW2:!1")
+ PORT_DIPSETTING( 0x01, DEF_STR( Upright ) )
+ PORT_DIPSETTING( 0x00, DEF_STR( Cocktail ) )
+ PORT_DIPUNUSED_DIPLOC( 0x02, 0x00, "SW2:!2" )
+ PORT_DIPUNUSED_DIPLOC( 0x04, 0x00, "SW2:!3" )
+ PORT_DIPUNUSED_DIPLOC( 0x08, 0x00, "SW2:!4" )
+ PORT_DIPUNUSED_DIPLOC( 0x10, 0x00, "SW2:!5" )
+ PORT_DIPUNUSED_DIPLOC( 0x20, 0x00, "SW2:!6" )
+ PORT_DIPUNUSED_DIPLOC( 0x40, 0x00, "SW2:!7" )
+ PORT_DIPUNUSED_DIPLOC( 0x80, 0x00, "SW2:!8" )
PORT_START("IN0")
PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_START1 )
PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_START2 )
- PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_BUTTON3 ) PORT_NAME ("Select Game 1")
- PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_BUTTON4 ) PORT_NAME ("Select Game 2")
- PORT_BIT( 0x10, IP_ACTIVE_HIGH, IPT_BUTTON5 ) PORT_NAME ("Select Game 3")
+ PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_BUTTON6 ) PORT_NAME("Button A") // Straight Pool
+ PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_BUTTON7 ) PORT_NAME("Button B") // Nine Ball
+ PORT_BIT( 0x10, IP_ACTIVE_HIGH, IPT_BUTTON8 ) PORT_NAME("Button C") // Snooker
PORT_BIT( 0x20, IP_ACTIVE_HIGH, IPT_COIN2 )
PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_COIN1 )
PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNUSED )
@@ -618,15 +628,22 @@ static INPUT_PORTS_START( tripool )
PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_COCKTAIL
PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_COCKTAIL
+ // 5 cue ball spin buttons, positioned in a "+" pattern
PORT_START("IN2")
- PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_BUTTON1 )
- PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_BUTTON2 ) // not needed?
- PORT_BIT( 0xfc, IP_ACTIVE_HIGH, IPT_UNUSED )
+ PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_BUTTON3 ) PORT_NAME("P1 Button Center")
+ PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_BUTTON1 ) PORT_NAME("P1 Button Up")
+ PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_BUTTON5 ) PORT_NAME("P1 Button Down")
+ PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_BUTTON4 ) PORT_NAME("P1 Button Right")
+ PORT_BIT( 0x10, IP_ACTIVE_HIGH, IPT_BUTTON2 ) PORT_NAME("P1 Button Left")
+ PORT_BIT( 0xe0, IP_ACTIVE_HIGH, IPT_UNUSED )
PORT_START("IN3")
- PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_BUTTON1 ) PORT_COCKTAIL
- PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_BUTTON2 ) PORT_COCKTAIL // not needed?
- PORT_BIT( 0xfc, IP_ACTIVE_HIGH, IPT_UNUSED )
+ PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_BUTTON3 ) PORT_COCKTAIL PORT_NAME("P2 Button Center")
+ PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_BUTTON1 ) PORT_COCKTAIL PORT_NAME("P2 Button Up")
+ PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_BUTTON5 ) PORT_COCKTAIL PORT_NAME("P2 Button Down")
+ PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_BUTTON4 ) PORT_COCKTAIL PORT_NAME("P2 Button Right")
+ PORT_BIT( 0x10, IP_ACTIVE_HIGH, IPT_BUTTON2 ) PORT_COCKTAIL PORT_NAME("P2 Button Left")
+ PORT_BIT( 0xe0, IP_ACTIVE_HIGH, IPT_UNUSED )
INPUT_PORTS_END
@@ -1614,6 +1631,7 @@ void jack_state::init_striv()
*
*************************************/
+// YEAR NAME PARENT MACHINE INPUT CLASS INIT SCREEN COMPANY, FULLNAME, FLAGS
GAME( 1982, jack, 0, jack, jack, jack_state, init_jack, ROT90, "Hara Industries (Cinematronics license)", "Jack the Giantkiller (set 1)", MACHINE_SUPPORTS_SAVE )
GAME( 1982, jack2, jack, jack, jack2, jack_state, init_jack, ROT90, "Hara Industries (Cinematronics license)", "Jack the Giantkiller (set 2)", MACHINE_SUPPORTS_SAVE )
GAME( 1982, jack3, jack, jack, jack3, jack_state, init_jack, ROT90, "Hara Industries (Cinematronics license)", "Jack the Giantkiller (set 3)", MACHINE_SUPPORTS_SAVE )
@@ -1622,8 +1640,8 @@ GAME( 1982, zzyzzyxx, 0, jack, zzyzzyxx, jack_state, init_zzyzzyxx,
GAME( 1982, zzyzzyxx2, zzyzzyxx, jack, zzyzzyxx, jack_state, init_zzyzzyxx, ROT90, "Cinematronics / Advanced Microcomputer Systems", "Zzyzzyxx (set 2)", MACHINE_SUPPORTS_SAVE )
GAME( 1982, brix, zzyzzyxx, jack, zzyzzyxx, jack_state, init_zzyzzyxx, ROT90, "Cinematronics / Advanced Microcomputer Systems", "Brix", MACHINE_SUPPORTS_SAVE )
GAME( 1984, freeze, 0, jack, freeze, jack_state, init_jack, ROT90, "Cinematronics", "Freeze", MACHINE_SUPPORTS_SAVE | MACHINE_NO_COCKTAIL )
-GAME( 1981, tripool, 0, jack, tripool, jack_state, init_jack, ROT90, "Noma (Casino Tech license)", "Tri-Pool (Casino Tech)", MACHINE_IMPERFECT_GRAPHICS | MACHINE_SUPPORTS_SAVE )
-GAME( 1981, tripoola, tripool, jack, tripool, jack_state, init_jack, ROT90, "Noma (Costal Games license)", "Tri-Pool (Costal Games)", MACHINE_IMPERFECT_GRAPHICS | MACHINE_SUPPORTS_SAVE )
+GAME( 1981, tripool, 0, jack, tripool, jack_state, init_jack, ROT90, "Noma (Casino Tech license)", "Tri-Pool: 3-In-One (Casino Tech)", MACHINE_IMPERFECT_GRAPHICS | MACHINE_SUPPORTS_SAVE )
+GAME( 1981, tripoola, tripool, jack, tripool, jack_state, init_jack, ROT90, "Noma (Coastal Games license)", "Tri-Pool: 3-In-One (Coastal Games)", MACHINE_IMPERFECT_GRAPHICS | MACHINE_SUPPORTS_SAVE )
GAME( 1984, sucasino, 0, jack, sucasino, jack_state, init_jack, ROT90, "Data Amusement", "Super Casino", MACHINE_SUPPORTS_SAVE )
GAME( 1985, striv, 0, striv, striv, jack_state, init_striv, ROT270, "Nova du Canada", "Super Triv (English questions)", MACHINE_IMPERFECT_SOUND | MACHINE_SUPPORTS_SAVE )
GAME( 1985, strivf, striv, striv, striv, jack_state, init_striv, ROT270, "Nova du Canada", "Super Triv (French questions)", MACHINE_IMPERFECT_SOUND | MACHINE_SUPPORTS_SAVE ) // Hara Industries PCB
diff --git a/src/mame/mame.lst b/src/mame/mame.lst
index e1029cd2915..aca45a8d284 100755
--- a/src/mame/mame.lst
+++ b/src/mame/mame.lst
@@ -39455,6 +39455,7 @@ dinokich // 2010.05 Konglongwang - D-Kids VS Alpha Yaosai
dinoki4 // 2008.08 Kodai Ouja Kyouryuu King - Mezame yo! Arata-naru Chikara!! (Japan, Ver 4.000) (MDA-C0061)
dinoking // 2005.09 Kodai Ouja Kyouryuu King / Ancient Ruler Dinosaur King
dinokior //
+isshoni // 2008.?? Isshoni Wanwan Waiwai Puppy 2008
huhimage // 2019.01 Heat Up Hockey Image (Ver.1.003R)
kingyo // 2009.10 Yataimura Kingyosukui (1-player, Japan, Ver 1.005)
kingyoch // 2009.03 Yataimura Kingyosukui (4-player, China, Ver 1.000)
diff --git a/src/mame/omron/luna_88k.cpp b/src/mame/omron/luna_88k.cpp
index 2f6411eab4b..9b6507a7092 100644
--- a/src/mame/omron/luna_88k.cpp
+++ b/src/mame/omron/luna_88k.cpp
@@ -9,9 +9,7 @@
* - OpenBSD source code
*
* TODO:
- * - scsi controller
* - xp i/o controller
- * - lance memory
* - crt controller
* - slotify graphics
* - expansion slots
@@ -19,7 +17,8 @@
* - multi-cpu configurations
*
* WIP:
- * - scsi probe/boot hangs
+ * - UniOS working
+ * - scsi issues with OpenBSD
*/
/*
@@ -165,8 +164,8 @@ private:
void irq_check();
- u16 net_r(offs_t offset) { return m_nram[offset >> 1]; }
- void net_w(offs_t offset, u16 data, u16 mem_mask) { COMBINE_DATA(&m_nram[offset >> 1]); }
+ u16 net_r(offs_t offset) { return m_nram[u16(offset >> 1)]; }
+ void net_w(offs_t offset, u16 data, u16 mem_mask) { COMBINE_DATA(&m_nram[u16(offset >> 1)]); }
required_device<mc88100_device> m_cpu;
required_device_array<mc88200_device, 2> m_cmmu;
@@ -221,6 +220,16 @@ void luna_88k_state::init()
void luna_88k_state::machine_start()
{
+ save_item(NAME(m_plane_active));
+ save_item(NAME(m_plane_func));
+ save_item(NAME(m_plane_mask));
+
+ save_item(NAME(m_irq_state));
+ save_item(NAME(m_irq_active));
+ save_item(NAME(m_irq_mask));
+
+ save_item(NAME(m_fzrom_addr));
+
m_nram = util::big_endian_cast<u16>(m_3port_ram.target());
}
@@ -271,6 +280,7 @@ void luna_88k_state::cpu_map(address_map &map)
[this](offs_t offset, u32 data) { irq(offset, 1, 1); }, "softint_set");
map(0x6b00'0000, 0x6b00'000f).lr32([this](offs_t offset) { irq(offset, 1, 0); return 0xffffffff; }, "softint_clr");
// 0x6d00'0000 reset cpu 0-3, all
+ map(0x6d00'0010, 0x6d00'0013).lw32([this](u32 data) { machine().schedule_soft_reset(); }, "reset");
map(0x7100'0000, 0x7101'ffff).ram().share("3port_ram");
@@ -278,11 +288,8 @@ void luna_88k_state::cpu_map(address_map &map)
// 0x8300'0000 ext board B
// 0x9000'0000 pc-98 ext board
// 0x9100'0000 pc-9801 irq 4
- //map(0x8000'0000, 0x9fff'ffff).noprw();
map(0x8000'0000, 0x9fff'ffff).lr32([this]() { m_cmmu[1]->bus_error_w(1); return 0; }, "bus_error");
- // 0xa100'0000 mask rom 0x400000
-
//map(0xb100'0000, 0xb100'ffff); // rfcnt (pad,vert_loc,pad,horiz_loc)
map(0xb104'0000, 0xb104'ffff).lw8([this](u8 data) { LOG("plane_active 0x%02x\n", data); m_plane_active = data; }, "plane_active");
map(0xb108'0000, 0xb10b'ffff).w(FUNC(luna_88k_state::plane_common_w));
@@ -367,6 +374,7 @@ void luna_88k_state::luna88k2(machine_config &config)
sys_clk.signal_handler().set([this](int state) { if (state) irq(0, 6, 1); });
DS1397(config, m_rtc, 32'768);
+ m_rtc->set_epoch(1990);
HD647180X(config, m_iop, 12'288'000);
m_iop->set_addrmap(AS_PROGRAM, &luna_88k_state::iop_map_mem);
@@ -503,7 +511,7 @@ void luna_88k_state::luna88k2(machine_config &config)
// TODO: crt timing control by HD6445CP4
screen_device &crt(SCREEN(config, "crt", SCREEN_TYPE_RASTER));
- crt.set_raw(108'992'000, 2048, 0, 2048, 1024, 0, 1024);
+ crt.set_raw(108'992'000, 2048, 0, 1280, 1024, 0, 1024);
crt.set_screen_update(FUNC(luna_88k_state::screen_update));
BT458(config, m_ramdac, 108'992'000);
@@ -680,9 +688,9 @@ void luna_88k_state::irq_check()
static INPUT_PORTS_START(luna88k)
PORT_START("SW1")
- PORT_DIPNAME(0x80, 0x00, "Start") PORT_DIPLOCATION("SW1:!1")
- PORT_DIPSETTING(0x00, "Autoboot")
- PORT_DIPSETTING(0x80, "Monitor")
+ PORT_DIPNAME(0x80, 0x80, "Start") PORT_DIPLOCATION("SW1:!1")
+ PORT_DIPSETTING(0x00, "Monitor") // single-user
+ PORT_DIPSETTING(0x80, "Autoboot") // multi-user
PORT_DIPNAME(0x40, 0x40, "Console") PORT_DIPLOCATION("SW1:!2")
PORT_DIPSETTING(0x00, "Serial")
PORT_DIPSETTING(0x40, "Graphics")
@@ -778,4 +786,4 @@ ROM_END
} // anonymous namespace
/* YEAR NAME PARENT COMPAT MACHINE INPUT CLASS INIT COMPANY FULLNAME FLAGS */
-COMP(1992?, luna88k2, 0, 0, luna88k2, luna88k, luna_88k_state, init, "Omron", u8"Luna 88K²", MACHINE_NOT_WORKING)
+COMP(1992?, luna88k2, 0, 0, luna88k2, luna88k, luna_88k_state, init, "Omron", u8"Luna 88K²", 0)
diff --git a/src/mame/sega/megatech.cpp b/src/mame/sega/megatech.cpp
index 9239607e214..bcdcba58a50 100644
--- a/src/mame/sega/megatech.cpp
+++ b/src/mame/sega/megatech.cpp
@@ -722,7 +722,7 @@ void mtech_state::megatech(machine_config &config)
io2.in_porte_cb().set(FUNC(mtech_state::bios_porte_r));
io2.out_porte_cb().set(FUNC(mtech_state::bios_porte_w));
- config.set_default_layout(layout_dualhovu);
+ config.set_default_layout(layout_dualhuov);
screen_device &screen(*subdevice<screen_device>("megadriv"));
screen.set_raw(XTAL(10'738'635)/2,
diff --git a/src/mame/sega/segasp.cpp b/src/mame/sega/segasp.cpp
index f5ea037f824..966103c7404 100644
--- a/src/mame/sega/segasp.cpp
+++ b/src/mame/sega/segasp.cpp
@@ -61,8 +61,8 @@ Disney: Magical Dream Dance on Stage ???-????? no
Future Police Patrol Chase ???-????? no ???-????-???? AAFE-xxxxxxxxxxx
Heat Up Hockey Image 834000201 TSB0-SEGA00001 CF JP ???-????-???? AAFE-xxxxxxxxxxx
Issyouni Turbo Drive ???-????? no ???-????-???? AAFE-01E91305101
-Issyouni Wanwan (INW 2K7 1ST) 834-14747 no ???-????-???? AAFE-xxxxxxxxxxx
-Issyouni Wanwan Waiwai Puppy (INW PUPPY) 834-14826 MDA-C0052 no ???-????-???? AAFE-xxxxxxxxxxx
+Isshoni Wanwan Waiwai Puppy 2008 834-14747 ROM 253-5508-0496J AAFE-01E34655005
+Isshoni Wanwan Waiwai Puppy (INW PUPPY) 834-14826 MDA-C0052 no ???-????-???? AAFE-xxxxxxxxxxx
King of Beetle: Battle Terminal ???-????? no ???-????-???? AAFE-xxxxxxxxxxx
Kouchu ouja Mushiking Popo no boukenhen 834-14583 no JP ???-????-???? AAFE-xxxxxxxxxxx
Love & Berry 2K5 Spring/Summer 834-14535 MDA-C0003 no JP ???-????-???? AAFE-xxxxxxxxxxx
@@ -498,6 +498,28 @@ ROM_START( dinoking )
ROM_LOAD( "317-0408-com.ic15", 0, 0x800, CRC(f77c49dc) SHA1(e10173bbbd5930ed159cec9a7dba308e2a3f3c43) )
ROM_END
+ROM_START( isshoni )
+ SEGASP_BIOS
+ ROM_DEFAULT_BIOS( "v201" )
+ SEGASP_JP
+ SEGASP_MISC
+
+ ROM_REGION( 0x20000000, "rom_board", ROMREGION_ERASEFF )
+ ROM_LOAD( "ic62", 0x00000000, 0x4000000, CRC(82a71af8) SHA1(368e197d4f5393506e1a0c6bcd31a1c4a650b6a6) )
+ ROM_LOAD( "ic63", 0x04000000, 0x4000000, CRC(d4f65679) SHA1(0921fc06d08c21c00607832c009f5b8f977f2b0f) )
+ ROM_LOAD( "ic64", 0x08000000, 0x4000000, CRC(28c764c8) SHA1(4c8c023e2da59f7f98c9d1ad6ff94a0ebfee7167) )
+ ROM_LOAD( "ic65", 0x0c000000, 0x4000000, CRC(906e7df8) SHA1(0553658ac3b1130203c993b2afe40359d65fab6f) )
+ ROM_LOAD( "ic66s", 0x10000000, 0x4000000, CRC(7815e178) SHA1(490eb5439ad2d2d38dbfdf659178522abc29e8f6) )
+ ROM_LOAD( "ic67s", 0x14000000, 0x4000000, CRC(8d2c6567) SHA1(42120e99364f33f856ff1085e19e9600d8ea009d) )
+ ROM_LOAD( "ic68s", 0x18000000, 0x4000000, CRC(d8213da3) SHA1(818bdceb326854c4d45bcbea309356e3e2c98051) )
+ // IC69S populated, empty
+
+ ROM_PARAMETER( ":rom_board:id", "5508" ) // 8x 512Mbit FlashROMs
+
+ ROM_REGION( 0x800, "pic_readout", 0 )
+ ROM_LOAD( "317-0496-jpn.ic15", 0, 0x800, CRC(7bca4250) SHA1(241c335deeaccd079028603432bf0f87185cb46d) )
+ROM_END
+
ROM_START( kingyo )
SEGASP_BIOS
ROM_DEFAULT_BIOS( "v201" )
@@ -905,6 +927,7 @@ GAME( 2009, bingogal,segasp, segasp, segasp, segasp_state, init_segasp, R
GAME( 2009, bingogals,segasp, segasp, segasp, segasp_state, init_segasp, ROT0, "Sega", "Bingo Galaxy (satellite)", GAME_FLAGS ) // 28.05.2009
GAME( 2009, brickppl,segasp, segasp, segasp, segasp_state, init_segasp, ROT0, "Sega", "Brick People / Block PeePoo (Ver 1.002)", GAME_FLAGS )
GAME( 2005, dinoking,segasp, segasp, segasp, segasp_state, init_segasp, ROT0, "Sega", "Dinosaur King (USA)", GAME_FLAGS )
+GAME( 2008, isshoni,segasp, segasp, segasp, segasp_state, init_segasp, ROT0, "Sega", "Isshoni Wanwan Waiwai Puppy 2008", GAME_FLAGS ) // いっしょにワンワンわいわいパピー 2008
GAME( 2009, kingyo,segasp, segasp, segasp, segasp_state, init_segasp, ROT0, "Sega", "Yataimura Kingyosukui (1-player, Japan, Ver 1.005)", GAME_FLAGS ) // キッズ屋台村 金魚すくい
GAME( 2006, lovebery,segasp, segasp, segasp, segasp_state, init_segasp, ROT0, "Sega", "Love And Berry - 1st-2nd Collection (Export, Ver 2.000)", GAME_FLAGS )
GAME( 2006, lovebero,lovebery, segasp, segasp, segasp_state, init_segasp, ROT0, "Sega", "Love And Berry - 1st-2nd Collection (Export, Ver 1.003)", GAME_FLAGS )
diff --git a/src/mame/skeleton/wicat.cpp b/src/mame/skeleton/wicat.cpp
index fa9a5217a64..7ec6d4a56a0 100644
--- a/src/mame/skeleton/wicat.cpp
+++ b/src/mame/skeleton/wicat.cpp
@@ -456,12 +456,12 @@ WRITE_LINE_MEMBER(wicat_state::crtc_irq_clear_w)
I8275_DRAW_CHARACTER_MEMBER(wicat_state::wicat_display_pixels)
{
- uint8_t romdata = vsp ? 0 : m_chargen->base()[(charcode << 4) | linecount];
+ uint16_t romdata = lten ? 0x3ff : vsp ? 0 : m_chargen->base()[(charcode << 4) | linecount];
pen_t const *const pen = m_palette->pens();
for (int i = 0; i < 10; i++)
{
- int color = ((romdata & 0xc0) != 0) ^ rvv;
+ int color = ((romdata & 0x300) != 0) ^ rvv;
bitmap.pix(y, x + i) = pen[color];
romdata <<= 1;
@@ -473,7 +473,7 @@ void wicat_state::wicat(machine_config &config)
M68000(config, m_maincpu, 8_MHz_XTAL);
m_maincpu->set_addrmap(AS_PROGRAM, &wicat_state::main_mem);
- MOS6522(config, m_via, 8_MHz_XTAL);
+ MOS6522(config, m_via, 8_MHz_XTAL / 10); // divider guessed
m_via->writepa_handler().set(FUNC(wicat_state::via_a_w));
m_via->writepb_handler().set(FUNC(wicat_state::via_b_w));
m_via->irq_handler().set_inputline(m_maincpu, M68K_IRQ_1);
diff --git a/src/osd/modules/netdev/taptun.cpp b/src/osd/modules/netdev/taptun.cpp
index a1b8d4d84ce..5196b6e7d2f 100644
--- a/src/osd/modules/netdev/taptun.cpp
+++ b/src/osd/modules/netdev/taptun.cpp
@@ -293,16 +293,21 @@ static std::vector<std::wstring> get_tap_adapters()
// check if the ComponentId value indicates a TAP-Windows adapter
if (RegQueryValueExW(unit_key, L"ComponentId", NULL, &data_type, LPBYTE(component_id), &component_id_len) == ERROR_SUCCESS
- && data_type == REG_SZ
- && safe_string(component_id, component_id_len) == L"" PRODUCT_TAP_WIN_COMPONENT_ID)
+ && data_type == REG_SZ)
{
- WCHAR net_cfg_instance_id[MAX_PATH];
- DWORD net_cfg_instance_id_len = sizeof(net_cfg_instance_id);
-
- // add the adapter to the result
- if (RegQueryValueExW(unit_key, L"NetCfgInstanceId", NULL, &data_type, LPBYTE(net_cfg_instance_id), &net_cfg_instance_id_len) == ERROR_SUCCESS
- && data_type == REG_SZ)
- result.push_back(safe_string(net_cfg_instance_id, net_cfg_instance_id_len));
+ std::wstring const value(safe_string(component_id, component_id_len));
+
+ // some older versions may not set the "root\" prefix
+ if (value == L"root\\" PRODUCT_TAP_WIN_COMPONENT_ID || value == L"" PRODUCT_TAP_WIN_COMPONENT_ID)
+ {
+ WCHAR net_cfg_instance_id[MAX_PATH];
+ DWORD net_cfg_instance_id_len = sizeof(net_cfg_instance_id);
+
+ // add the adapter to the result
+ if (RegQueryValueExW(unit_key, L"NetCfgInstanceId", NULL, &data_type, LPBYTE(net_cfg_instance_id), &net_cfg_instance_id_len) == ERROR_SUCCESS
+ && data_type == REG_SZ)
+ result.push_back(safe_string(net_cfg_instance_id, net_cfg_instance_id_len));
+ }
}
RegCloseKey(unit_key);
diff --git a/src/devices/machine/t10mmc.cpp b/src/devices/machine/t10mmc.cpp
index f6cbd78b6a1..0d2cee2d0ad 100644
--- a/src/devices/machine/t10mmc.cpp
+++ b/src/devices/machine/t10mmc.cpp
@@ -345,11 +345,17 @@ void t10mmc::ExecCommand()
break;
}
+ // [4] track start
+ // [5] index start
+ // [7] track end
+ // [8] index end
if (command[4] > command[7])
{
// TODO: check error
set_sense(SCSI_SENSE_KEY_ILLEGAL_REQUEST, SCSI_SENSE_ASC_ASCQ_AUDIO_PLAY_OPERATION_STOPPED_DUE_TO_ERROR);
m_status_code = SCSI_STATUS_CODE_CHECK_CONDITION;
+
+ m_device->logerror("Error: start TNO (%d,%d) > end TNO (%d,%d)\n", command[4], command[5], command[7], command[8]);
}
else
{
@@ -360,12 +366,16 @@ void t10mmc::ExecCommand()
if (end_track > command[7])
end_track = command[7];
- // HACK: assume index 0 & 1 means beginning of track and anything else means end of track
- if (command[8] <= 1)
- end_track--;
+ // konamigv lacrazyc just sends same track start/end
+ if (command[4] != command[7] && command[5] != command[8])
+ {
+ // HACK: assume index 0 & 1 means beginning of track and anything else means end of track
+ if (command[8] <= 1)
+ end_track--;
- if (m_sotc)
- end_track = command[4];
+ if (m_sotc)
+ end_track = command[4];
+ }
m_lba = m_cdrom->get_track_start(command[4] - 1);
m_blocks = m_cdrom->get_track_start(end_track) - m_lba;
@@ -376,6 +386,7 @@ void t10mmc::ExecCommand()
m_cdda->start_audio(m_lba, m_blocks);
m_audio_sense = SCSI_SENSE_ASC_ASCQ_AUDIO_PLAY_OPERATION_IN_PROGRESS;
m_status_code = SCSI_STATUS_CODE_GOOD;
+ m_device->logerror("Starting audio TNO %d LBA %d blocks %d\n", trk, m_lba, m_blocks);
}
else
{
diff --git a/src/devices/sound/msm5232.cpp b/src/devices/sound/msm5232.cpp
index 0e8a8676f5e..b7090aaef0a 100644
--- a/src/devices/sound/msm5232.cpp
+++ b/src/devices/sound/msm5232.cpp
@@ -110,7 +110,7 @@ void msm5232_device::device_reset()
void msm5232_device::device_stop()
{
- #ifdef SAVE_SAMPLE
+#ifdef SAVE_SAMPLE
fclose(sample[8]);
#endif
#ifdef SAVE_SEPARATE_CHANNELS
@@ -127,22 +127,22 @@ void msm5232_device::device_stop()
void msm5232_device::set_capacitors(double cap1, double cap2, double cap3, double cap4, double cap5, double cap6, double cap7, double cap8)
{
- m_external_capacity[0] = cap1;
- m_external_capacity[1] = cap2;
- m_external_capacity[2] = cap3;
- m_external_capacity[3] = cap4;
- m_external_capacity[4] = cap5;
- m_external_capacity[5] = cap6;
- m_external_capacity[6] = cap7;
- m_external_capacity[7] = cap8;
+ m_external_capacitance[0] = cap1;
+ m_external_capacitance[1] = cap2;
+ m_external_capacitance[2] = cap3;
+ m_external_capacitance[3] = cap4;
+ m_external_capacitance[4] = cap5;
+ m_external_capacitance[5] = cap6;
+ m_external_capacitance[6] = cap7;
+ m_external_capacitance[7] = cap8;
}
-/* Default chip clock is 2119040 Hz */
-/* At this clock chip generates exactly 440.0 Hz signal on 8' output when pitch data=0x21 */
+// Default chip clock is 2119040 Hz
+// At this clock chip generates exactly 440.0 Hz signal on 8' output when pitch data=0x21
-/* ROM table to convert from pitch data into data for programmable counter and binary counter */
-/* Chip has 88x12bits ROM (addressing (in hex) from 0x00 to 0x57) */
+// ROM table to convert from pitch data into data for programmable counter and binary counter
+// Chip has 88x12bits ROM (addressing (in hex) from 0x00 to 0x57)
#define ROM(counter,bindiv) (counter|(bindiv<<9))
static const uint16_t MSM5232_ROM[88]={
@@ -199,7 +199,7 @@ static FILE *sample[9];
/*
* Resistance values are guesswork, default capacity is mentioned in the datasheets
*
* Two errors in the datasheet, one probable, one certain
* - it mentions 0.39uF caps, but most boards have 1uF caps and expect datasheet timings
@@ -280,9 +280,9 @@ void msm5232_device::init_tables()
void msm5232_device::init_voice(int i)
{
- m_voi[i].ar_rate= m_ar_tbl[0] * m_external_capacity[i];
- m_voi[i].dr_rate= m_dr_tbl[0] * m_external_capacity[i];
- m_voi[i].rr_rate= m_dr_tbl[0] * m_external_capacity[i]; /* this is constant value */
+ m_voi[i].ar_rate= m_ar_tbl[0] * m_external_capacitance[i];
+ m_voi[i].dr_rate= m_dr_tbl[0] * m_external_capacitance[i];
+ m_voi[i].rr_rate= m_dr_tbl[0] * m_external_capacitance[i]; /* this is constant value */
m_voi[i].eg_sect= -1;
m_voi[i].eg = 0.0;
m_voi[i].eg_arm = 0;
@@ -387,22 +387,22 @@ void msm5232_device::write(offs_t offset, uint8_t data)
{
case 0x08: /* group1 attack */
for (i=0; i<4; i++)
- m_voi[i].ar_rate = m_ar_tbl[data&0x7] * m_external_capacity[i];
+ m_voi[i].ar_rate = m_ar_tbl[data&0x7] * m_external_capacitance[i];
break;
case 0x09: /* group2 attack */
for (i=0; i<4; i++)
- m_voi[i+4].ar_rate = m_ar_tbl[data&0x7] * m_external_capacity[i+4];
+ m_voi[i+4].ar_rate = m_ar_tbl[data&0x7] * m_external_capacitance[i+4];
break;
case 0x0a: /* group1 decay */
for (i=0; i<4; i++)
- m_voi[i].dr_rate = m_dr_tbl[data&0xf] * m_external_capacity[i];
+ m_voi[i].dr_rate = m_dr_tbl[data&0xf] * m_external_capacitance[i];
break;
case 0x0b: /* group2 decay */
for (i=0; i<4; i++)
- m_voi[i+4].dr_rate = m_dr_tbl[data&0xf] * m_external_capacity[i+4];
+ m_voi[i+4].dr_rate = m_dr_tbl[data&0xf] * m_external_capacitance[i+4];
break;
case 0x0c: /* group1 control */
@@ -199,7 +199,7 @@ static FILE *sample[9];
/*
- * Resistance values are guesswork, default capacity is mentioned in the datasheets
+ * Resistance values are guesswork, default capacitance is mentioned in the datasheets
*
* Two errors in the datasheet, one probable, one certain